/*
 * $Id: back_alt.c,v 1.1 2004/09/16 16:43:31 alexanto Exp Alessandro $
 *
 * $Boeing 767 Gauge Pack - (C) 2004 Alessandro Antonini, Central Park Informatica $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Desc: The standby altimeter gauge $
 *
 * $Log: back_alt.c,v $
 * Revision 1.1  2004/09/16 16:43:31  alexanto
 * Initial revision
 *
 */

/*
 *  Set up gauge header
 */
char backup_altimeter_gauge_name[]	= 	GAUGE_NAME;
extern PELEMENT_HEADER      backup_altimeter_list;
extern MOUSERECT            backup_altimeter_rect[];


/*
 * forward declarations
 */
PELEMENT_HEADER backup_altimeter_altitude_string_list[];
PELEMENT_HEADER backup_altimeter_baro_pressure_string_list[];
PELEMENT_HEADER backup_altimeter_bg_list[];

void FSAPI backup_altimeter_gaugeproc(PGAUGEHDR, int, UINT32);
FLOAT64 FSAPI backup_altimeter_baro_pressure_string_cb(PELEMENT_STRING pelement);
FLOAT64 FSAPI backup_altimeter_altitude_string_cb(PELEMENT_STRING pelement);
FLOAT64 FSAPI backup_altimeter_needle_cb(PELEMENT_NEEDLE);

GAUGE_HEADER_FS700( GAUGE_W, backup_altimeter_gauge_name, &backup_altimeter_list, \
					backup_altimeter_rect, backup_altimeter_gaugeproc, 0, 0, 0);

FAILURE_RECORD backup_altimeter_baro_pressure_string_fail[] =
{
	{FAIL_SYSTEM_ELECTRICAL_PANELS, FAIL_ACTION_NO_DRAW},
	{FAIL_SYSTEM_ELECTRICAL_AVIONICS, FAIL_ACTION_NO_DRAW},
	{FAIL_NONE, FAIL_ACTION_NONE}
};

FAILURE_RECORD backup_altimeter_altitude_string_fail[] =
{
	{FAIL_SYSTEM_ELECTRICAL_PANELS, FAIL_ACTION_NO_DRAW},
	{FAIL_SYSTEM_ELECTRICAL_AVIONICS, FAIL_ACTION_NO_DRAW},
	{FAIL_GAUGE_ALTIMETER, FAIL_ACTION_FREEZE},
	{FAIL_SYSTEM_PITOT_STATIC, FAIL_ACTION_FREEZE},
	{FAIL_NONE, FAIL_ACTION_NONE}
};

FAILURE_RECORD backup_altimeter_altitude_needle_fail[] =
{
	{FAIL_SYSTEM_ELECTRICAL_PANELS, FAIL_ACTION_NO_DRAW},
	{FAIL_SYSTEM_ELECTRICAL_AVIONICS, FAIL_ACTION_NO_DRAW},
	{FAIL_GAUGE_ALTIMETER, FAIL_ACTION_FREEZE},
	{FAIL_SYSTEM_PITOT_STATIC, FAIL_ACTION_FREEZE},
	{FAIL_NONE, FAIL_ACTION_NONE}
};


/*
 * altimeter needle
 */
MAKE_NEEDLE
(    
	backup_altimeter_needle,
	BMP_BACKUP_ALTIMETER_NEEDLE,
	NULL,
	backup_altimeter_altitude_needle_fail,
	IMAGE_USE_TRANSPARENCY | IMAGE_USE_ERASE | IMAGE_USE_BRIGHT,
	0,
	{ 74, 74 },
	{ 5, 54 },
	MODULE_VAR_NONE,
	backup_altimeter_needle_cb,
	NULL,
	8 
)


/*
 * altitude string
 */
MAKE_STRING
(
	backup_altimeter_altitude_string,
	&backup_altimeter_altitude_string_list,
	backup_altimeter_altitude_string_fail,
	IMAGE_USE_ERASE,
	0,
	{ 87, 62 },
	{ 20, 19 },
	2,
	MODULE_VAR_NONE,
	MODULE_VAR_NONE,
	MODULE_VAR_NONE,
	RGB(189,189,189),
	RGB(4,4,4),
	RGB(192,192,192),
	FONT_COURIER,
	GAUGE_WEIGHT_DEFAULT,
	DEFAULT_CHARSET,
	0,
	DT_VCENTER | DT_SINGLELINE | DT_LEFT,
	NULL,
	backup_altimeter_altitude_string_cb
)

/*
 * barometric pressure string
 */
MAKE_STRING
(
	backup_altimeter_baro_pressure_string,
	&backup_altimeter_baro_pressure_string_list,
	backup_altimeter_baro_pressure_string_fail,
	IMAGE_USE_ERASE,
	0,
	{ 50, 88 },
	{ 50, 15 },
	5,
	MODULE_VAR_NONE,
	MODULE_VAR_NONE,
	MODULE_VAR_NONE,
	RGB(189,189,189),
	RGB(4,4,4),
	RGB(192,192,192),
	FONT_COURIER,
	GAUGE_WEIGHT_DEFAULT,
	DEFAULT_CHARSET,
	0,
	DT_VCENTER | DT_SINGLELINE | DT_LEFT,
	NULL,
	backup_altimeter_baro_pressure_string_cb
)


/*
 * card background image
 */
MAKE_STATIC
(
    backup_altimeter_bg,
    BMP_BACKUP_ALTIMETER_BG,
    &backup_altimeter_bg_list,
    NULL,
	transparent | IMAGE_USE_ERASE,
	0,
	0,0
)

/*
 * priority lists
 */
PELEMENT_HEADER backup_altimeter_altitude_string_list[] =
{
	&backup_altimeter_needle.header,
	NULL
};
PELEMENT_HEADER backup_altimeter_baro_pressure_string_list[] =
{
	&backup_altimeter_altitude_string.header,
	NULL
};
PELEMENT_HEADER backup_altimeter_bg_list[] =
{
	&backup_altimeter_baro_pressure_string.header,
	NULL
};


extern PELEMENT_HEADER      backup_altimeter_list = &backup_altimeter_bg.header;

MOUSERECT backup_altimeter_rect[] =
{
    MOUSE_PARENT_BEGIN( 0, 0, 0, 0, HELPID_GAUGE_BACKUP_ALTIMETER )
	    MOUSE_PARENT_BEGIN( 8, 112, 28, 28, HELPID_GAUGE_ALTIMETER_SET )
		    MOUSE_CHILD_EVENT( 0, 0, 14, 28, CURSOR_DOWNARROW, MOUSE_LEFTSINGLE | MOUSE_DOWN_REPEAT, KEY_KOHLSMAN_DEC )
			MOUSE_CHILD_EVENT( 14, 0, 14, 28, CURSOR_UPARROW, MOUSE_LEFTSINGLE | MOUSE_DOWN_REPEAT, KEY_KOHLSMAN_INC )
		MOUSE_PARENT_END
	MOUSE_PARENT_END
    { MOUSE_RECT_EOL, { 0, 0, 0, 0 }, CURSOR_NONE, HELP_NONE, MOUSE_NONE, 0, NULL, NULL }
};




#undef		GAUGE_NAME
#undef		GAUGEHDR_VAR_NAME
#undef		GAUGE_W


////////////////////////////////////////////////////////////////////////////////
// gauge initialization proc
////////////////////////////////////////////////////////////////////////////////
void FSAPI backup_altimeter_gaugeproc( PGAUGEHDR pgauge, int service_id, UINT32 extra_data )
{
	
	switch(service_id)
	{
	case PANEL_SERVICE_PRE_INSTALL:		// install_routine()
		break;

	case PANEL_SERVICE_PRE_INITIALIZE:	// initialize_routine()
		break;

	case PANEL_SERVICE_PRE_UPDATE:		// update_routine()

		if (bPanelLightOn)	// if panel lights, brighten all elements
		{
			BRIGHT_IMG(pgauge->elements_list[0]);
			BRIGHT_IMG(pgauge->elements_list[0]->N_E[0]);
			BRIGHT_IMG(pgauge->elements_list[0]->N_E[0]->N_E[0]);
			BRIGHT_IMG(pgauge->elements_list[0]->N_E[0]->N_E[0]->N_E[0]);
		}
		else							// otherwise darken them
		{
			DARK_IMG(pgauge->elements_list[0]);	
			DARK_IMG(pgauge->elements_list[0]->N_E[0]);	
			DARK_IMG(pgauge->elements_list[0]->N_E[0]->N_E[0]);	
			DARK_IMG(pgauge->elements_list[0]->N_E[0]->N_E[0]->N_E[0]);
    	}
		break;

	case PANEL_SERVICE_PRE_DRAW:		// draw_routine()
		break;

	case PANEL_SERVICE_PRE_KILL:		// kill_routine()
		break;
	}
}

/*
 * update baro pressure string
 */
FLOAT64 FSAPI backup_altimeter_baro_pressure_string_cb(PELEMENT_STRING pelement)
{
	FLOAT64 f, alt_atm, alt_pressure_in;
	lookup_var(&baro_pressure);
	f = baro_pressure.var_value.n;
	alt_atm = f/1013.25;
	alt_pressure_in = alt_atm * 29.92;
	sprintf(pelement->string, "%2.2f", alt_pressure_in);
	return f;
}

/*
 * update baro altitude string
 */
FLOAT64 FSAPI backup_altimeter_altitude_string_cb(PELEMENT_STRING pelement)
{
	lookup_var(&baro_alt);
	wsprintf(pelement->string, "%0.2d", (int)baro_alt.var_value.n/1000);
	return baro_alt.var_value.n;
}

/*
 * update baro altitude needle
 */
FLOAT64 FSAPI backup_altimeter_needle_cb(PELEMENT_NEEDLE pelement)
{
	UINT32 i = baro_alt_hund;
	UINT32 j = i;
	j =  j * 360 / 100;
	return  j;
}
