/*
 * $Id: bkairspd.c,v 1.1 2004/09/16 16:43:31 alexanto Exp Alessandro $
 *
 * $Boeing 767 Gauge Pack - (C) 2004 Alessandro Antonini, Central Park Informatica $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Desc: The backup airspeed gauge $
 *
 * $Log: bkairspd.c,v $
 * Revision 1.1  2004/09/16 16:43:31  alexanto
 * Initial revision
 *
 */

/*
 *  Set up gauge header
 */
char backup_airspeed_gauge_name[]	= GAUGE_NAME;
extern PELEMENT_HEADER      backup_airspeed_list;
extern MOUSERECT            backup_airspeed_rect[];

/*
 * forward declarations
 */
PELEMENT_HEADER      backup_airspeed_bg_list[];

void FSAPI backup_airspeedgaugeproc(PGAUGEHDR, int, UINT32);
FLOAT64 FSAPI backup_airspeed_needle_cb(PELEMENT_NEEDLE);

GAUGE_HEADER_FS700( GAUGE_W, backup_airspeed_gauge_name, &backup_airspeed_list, \
					backup_airspeed_rect, backup_airspeedgaugeproc, 0, 0, 0);

FAILURE_RECORD backup_airspeed_needle_fail[] =
{
	{FAIL_SYSTEM_ELECTRICAL_PANELS, FAIL_ACTION_FREEZE},
	{FAIL_SYSTEM_ELECTRICAL_AVIONICS, FAIL_ACTION_FREEZE},
	{FAIL_GAUGE_AIRSPEED, FAIL_ACTION_FREEZE},
	{FAIL_SYSTEM_PITOT_STATIC, FAIL_ACTION_FREEZE},
	{FAIL_NONE, FAIL_ACTION_NONE}
};

NONLINEARITY backup_airspeed_needle_nonlinearity[] =
{
   {{  91,   15}, 60, 0},
   {{ 128,   26}, 80, 0},
   {{ 155,   51}, 100, 0},
   {{ 163,   89}, 120, 0},
   {{ 153,  124}, 140, 0},
   {{ 129,  152}, 160, 0},
   {{ 108,  161}, 180, 0},
   {{  85,  164}, 200, 0},
   {{  36,  137}, 250, 0},
   {{  22,  107}, 300, 0},
   {{  21,   73}, 350, 0},
   {{  36,   45}, 400, 0},
   {{  61,   25}, 450, 0}
};


/*
 * airspeed needle
 */ 
MAKE_NEEDLE
(    
	backup_airspeed_needle,
	BMP_BACKUP_AIRSPEED_NEEDLE,
	NULL,
	backup_airspeed_needle_fail,
	IMAGE_USE_TRANSPARENCY | IMAGE_USE_ERASE,
	0,
	{ 90, 89 },
	{ 5, 5 },
	//{ 90, 0 },
	MODULE_VAR_NONE,
	backup_airspeed_needle_cb,
	backup_airspeed_needle_nonlinearity,
	6 
)


/*
 * card background image
 */
MAKE_STATIC
(
    backup_airspeed_bg,
    BMP_BACKUP_AIRSPEED_BG,
    &backup_airspeed_bg_list,
    NULL,
	IMAGE_USE_TRANSPARENCY | IMAGE_USE_ERASE,
	0,
	0,0
)


/*
 * priority lists
 */
PELEMENT_HEADER      backup_airspeed_bg_list[] =
{
	&backup_airspeed_needle.header,
	NULL
};



extern PELEMENT_HEADER      backup_airspeed_list = &backup_airspeed_bg.header;


MOUSERECT backup_airspeed_rect[] =
{
	MOUSE_PARENT_BEGIN( 0, 0, 0, 0, HELPID_GAUGE_BACKUP_AIRSPEED )
	MOUSE_PARENT_END
	{
		MOUSE_RECT_EOL, { 0, 0, 0, 0 }, CURSOR_NONE, HELP_NONE, MOUSE_NONE, 0, NULL, NULL
	}
};


////////////////////////////////////////////////////////////////////////////////
// gauge initialization proc
////////////////////////////////////////////////////////////////////////////////
void FSAPI backup_airspeedgaugeproc( PGAUGEHDR pgauge, int service_id, UINT32 extra_data )
{
	switch(service_id)
	{
	case PANEL_SERVICE_PRE_INSTALL:		// install_routine()
		break;

	case PANEL_SERVICE_PRE_INITIALIZE:	// initialize_routine()
		break;

	case PANEL_SERVICE_PRE_UPDATE:		// update_routine()
		if (bPanelLightOn)	// if panel lights, brighten all elements
		{
			BRIGHT_IMG(pgauge->elements_list[0]);
			BRIGHT_IMG(pgauge->elements_list[0]->N_E[0]);
		}
		else							// otherwise darken them
		{
			DARK_IMG(pgauge->elements_list[0]);
			DARK_IMG(pgauge->elements_list[0]->N_E[0]);
    	}
		break;

	case PANEL_SERVICE_PRE_DRAW:		// draw_routine()
		break;

	case PANEL_SERVICE_PRE_KILL:		// kill_routine()
		break;
	}
}

#undef GAUGE_NAME
#undef GAUGEHDR_VAR_NAME
#undef GAUGE_W

/*
 * update airspeed needle
 */
FLOAT64 FSAPI backup_airspeed_needle_cb(PELEMENT_NEEDLE pelement)
{
	FLOAT64	dir;
    lookup_var(&airspeed);
	dir = airspeed.var_value.n;
	if (dir>450)
		dir = 450;
	else if (dir<60)
		dir=60;
	return dir;
}
