/*
 * $Id: clock.c,v 1.1 2004/09/16 16:43:31 alexanto Exp Alessandro $
 *
 * $Boeing 767 Gauge Pack - (C) 2004 Alessandro Antonini, Central Park Informatica $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Desc: The clock gauge $
 *
 * $Log: clock.c,v $
 * Revision 1.1  2004/09/16 16:43:31  alexanto
 * Initial revision
 *
 */

/*
 *  Set up gauge header
 */
char clock_gauge_name[]     = GAUGE_NAME;
extern PELEMENT_HEADER      clock_list;
extern MOUSERECT            clock_rect[];


/*
 * forward declarations
 */
PELEMENT_HEADER clock_elapsed_minutes_list[];
PELEMENT_HEADER clock_simrate_speed_list[];


void FSAPI clockgaugeproc(PGAUGEHDR, int, UINT32);
FLOAT64 FSAPI clock_simrate_string_cb(PELEMENT_STRING pelement);
FLOAT64 FSAPI clock_elapsed_minutes_cb(PELEMENT_STRING pelement);
FLOAT64 FSAPI clock_needle_cb(PELEMENT_NEEDLE pelement);

GAUGE_HEADER_FS700(GAUGE_W, clock_gauge_name, &clock_list, \
                        clock_rect, clockgaugeproc, 0, 0, 0);

/*
 * seconds needle
 */
MAKE_NEEDLE
(
	clock_needle,
	BMP_CLOCK_NEEDLE,
	NULL,
	NULL,
	IMAGE_USE_TRANSPARENCY | IMAGE_USE_ERASE,
	0,
	{ 72, 72 },
	{ 5, 5 },
	//{ 90, 0 },
	MODULE_VAR_NONE,
	clock_needle_cb,
	NULL,
	0
)


/*
 * elapsed minutes string
 */
MAKE_STRING
(
	clock_elapsed_minutes,
	&clock_elapsed_minutes_list,
	NULL,
	IMAGE_USE_ERASE | transparent,
	0,
	{ 50, 40 },
    { 45, 19 },
	4,

	ELAPSED_SECONDS,
	MODULE_VAR_NONE,
	MODULE_VAR_NONE,
	CL_AMBRA,
	RGB(4,4,4),
	CL_WHITE,
	FONT_QUARTZ,
	GAUGE_WEIGHT_DEFAULT,
	DEFAULT_CHARSET,
	0,
	DT_VCENTER | DT_SINGLELINE | DT_LEFT,
	NULL,
	clock_elapsed_minutes_cb
)

/*
 * simulation rate string
 */
MAKE_STRING
(
	clock_simrate_speed,
	&clock_simrate_speed_list,
	NULL,
	IMAGE_USE_ERASE | transparent,
	0,
	{ 50, 87 },
    { 45, 19 },
	4,

	SIM_SPEED,
	MODULE_VAR_NONE,
	MODULE_VAR_NONE,
	CL_AMBRA,
	RGB(4,4,4),
	CL_WHITE,
	FONT_QUARTZ,
	GAUGE_WEIGHT_DEFAULT,
	DEFAULT_CHARSET,
	0,
	DT_VCENTER | DT_SINGLELINE | DT_LEFT,
	NULL,
	clock_simrate_string_cb
)

/*
 * priority lists
 */
PELEMENT_HEADER clock_elapsed_minutes_list[] =
{
	&clock_needle.header,
	NULL
};
PELEMENT_HEADER clock_simrate_speed_list[] =
{
	&clock_elapsed_minutes.header,
	NULL
};
PELEMENT_HEADER clock_bg_list[] =
{
	&clock_simrate_speed.header,
	NULL
};




/*
 * card background image
 */
MAKE_STATIC
(
    clock_background,
    BMP_CLOCK_BG,
    &clock_bg_list,
    NULL,
	IMAGE_USE_TRANSPARENCY | IMAGE_USE_ERASE,
	0,
	0,0
)


////////////////////////////////////////////////////////////////////////////////
// header
////////////////////////////////////////////////////////////////////////////////
PELEMENT_HEADER     clock_list   = &clock_background.header;


////////////////////////////////////////////////////////////////////////////////
MOUSERECT clock_rect[] =
{
	MOUSE_PARENT_BEGIN( 0, 0, 0, 0, HELP_NONE )

    	MOUSE_PARENT_BEGIN( 41, 78, 53, 27, HELPID_GAUGE_SIM_RATE )
	        MOUSE_CHILD_EVENT( 0, 0, 26, 27, CURSOR_DOWNARROW, MOUSE_LEFTSINGLE, KEY_SIM_RATE_DECR )
        	MOUSE_CHILD_EVENT( 26, 0, 27, 27, CURSOR_UPARROW, MOUSE_LEFTSINGLE, KEY_SIM_RATE_INCR )
    	MOUSE_PARENT_END
	    MOUSE_PARENT_BEGIN( 11, 7, 102, 15, HELPID_GAUGE_CLOCK )
   		    MOUSE_CHILD_EVENT( 0, 0, 13, 15, CURSOR_DOWNARROW, MOUSE_LEFTSINGLE, KEY_CLOCK_HOURS_DEC )
       		MOUSE_CHILD_EVENT( 13, 0, 13, 15, CURSOR_UPARROW, MOUSE_LEFTSINGLE, KEY_CLOCK_HOURS_INC )
	        MOUSE_CHILD_EVENT( 37, 0, 13, 15, CURSOR_DOWNARROW, MOUSE_LEFTSINGLE, KEY_CLOCK_MINUTES_DEC )
   		    MOUSE_CHILD_EVENT( 50, 0, 13, 15, CURSOR_UPARROW, MOUSE_LEFTSINGLE, KEY_CLOCK_MINUTES_INC )
       		MOUSE_CHILD_EVENT( 76, 0, 26, 15, CURSOR_HAND, MOUSE_LEFTSINGLE, KEY_CLOCK_SECONDS_ZERO )
	    MOUSE_PARENT_END
	MOUSE_PARENT_END
	{
		MOUSE_RECT_EOL, { 0, 0, 0, 0 }, CURSOR_NONE, HELP_NONE, MOUSE_NONE, 0, NULL, NULL
	}
};


////////////////////////////////////////////////////////////////////////////////
// gauge initialization proc
////////////////////////////////////////////////////////////////////////////////
void FSAPI clockgaugeproc( PGAUGEHDR pgauge, int service_id, UINT32 extra_data )
{
	switch(service_id)
	{
	case PANEL_SERVICE_PRE_INSTALL: /* "install_routine()" */
		break;

	case PANEL_SERVICE_PRE_INITIALIZE:	/* "initialize_routine()" */
		break;

	case PANEL_SERVICE_PRE_UPDATE: /* "update_routine()" */
		if (bPanelLightOn)	// if panel lights, brighten all elements
		{
			BRIGHT_IMG(pgauge->elements_list[0]);
			BRIGHT_IMG(pgauge->elements_list[0]->N_E[0]);
			BRIGHT_IMG(pgauge->elements_list[0]->N_E[0]->N_E[0]);
			BRIGHT_IMG(pgauge->elements_list[0]->N_E[0]->N_E[0]->N_E[0]);
		}
		else
		{
			DARK_IMG(pgauge->elements_list[0]);
			DARK_IMG(pgauge->elements_list[0]->N_E[0]);
			DARK_IMG(pgauge->elements_list[0]->N_E[0]->N_E[0]);
			DARK_IMG(pgauge->elements_list[0]->N_E[0]->N_E[0]->N_E[0]);
		}
		break;

	case PANEL_SERVICE_PRE_DRAW: /* "draw_routine()" */
		break;

	case PANEL_SERVICE_PRE_KILL: /* "kill_routine()" */
		break;
	}
}



#undef GAUGE_NAME
#undef GAUGEHDR_VAR_NAME
#undef GAUGE_W

/*
 * sim rate update
 */
FLOAT64 FSAPI clock_simrate_string_cb(PELEMENT_STRING pelement)
{
	FLOAT64 f = pelement->source_var[0].var_value.n;
	if (f>=1.0)
		sprintf(pelement->string,"%0.1f", f);
	else
		sprintf(pelement->string,"%0.2f", f);
	return f;
}

/*
 * elapsed minutes update
 */
FLOAT64 FSAPI clock_elapsed_minutes_cb(PELEMENT_STRING pelement)
{
	FLOAT64 f = pelement->source_var[0].var_value.n;
	wsprintf(pelement->string,"%0.4d",(int)f/60);
	return f;
}

/*
 * seconds needle update
 */
FLOAT64 FSAPI clock_needle_cb(PELEMENT_NEEDLE pelement)
{
	return ((FSeconds * 360) / 60)-90;
}

