/*
 * $Id: cpb767.c,v 1.1 2004/09/16 16:43:31 alexanto Exp Alessandro $
 *
 * $Boeing 767 Gauge Pack - (C) 2004 Alessandro Antonini, Central Park Informatica $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Desc: Main File $
 *
 * $Log: cpb767.c,v $
 * Revision 1.1  2004/09/16 16:43:31  alexanto
 * Initial revision
 *
 */

#include <stdio.h>			// for sprintf
#include <math.h>
#include "gauges.h"
#include "resource.h"
#include "fssound.h"

// the second one uses a sound file in the main FS sound folder
MFSSoundResVars(main_sound, SOUND_CLICK);

FLOAT64	TasFromMachTat(FLOAT64 dblTatC,FLOAT64 dblMach)
{
	//returns true airspeed in knots
	//input:
	//      true air temperature in degrees centigrade
	//      mach number
	return 39.0*dblMach*sqrt((dblTatC+273.15)/(1+0.2*dblMach*dblMach));
}


/*
 * global flight simulator vars
 */
BOOL NoSmokingSign = TRUE;
BOOL FastenSeatBelts = TRUE;


MODULE_VAR avlights = {PANEL_LIGHTS};
MODULE_VAR hsi_obi_needle = {HSI_OBI_NEEDLE};
MODULE_VAR vor1_obi = {VOR1_OBI};
MODULE_VAR mach = {AUTOPILOT_MACH_HOLD_VAR};
MODULE_VAR mach_in = {AUTOPILOT_MACH_HOLD};
MODULE_VAR AltitudeLockVar = {AUTOPILOT_ALTITUDE_LOCK_VAR};
MODULE_VAR flight_director_active = {FLIGHT_DIRECTOR_ACTIVE};
MODULE_VAR units_of_measure = {DISPLAY_UNITS};
MODULE_VAR airspeed = {AIRSPEED};
MODULE_VAR mach_speed = {MACH};
MODULE_VAR baro_alt = {ALT_FROM_BAROMETRIC_PRESSURE};
MODULE_VAR baro_pressure = {KOHLSMAN_SETTING_MB};
MODULE_VAR glideslope_active = {HSI_HORIZONTAL_VALID};
MODULE_VAR deviation_active = {HSI_VERTICAL_VALID};
MODULE_VAR dme1_distance = {DME1_DISTANCE};
MODULE_VAR dme2_distance = {DME2_DISTANCE};
MODULE_VAR dme1_speed = {DME1_SPEED};
MODULE_VAR dme2_speed = {DME2_SPEED};
MODULE_VAR cur_dme = {CURRENT_DME};
MODULE_VAR plane_heading_degrees_gyro = {PLANE_HEADING_DEGREES_GYRO};
MODULE_VAR vor2_needle = {NAV2_VOR_RADIAL};
MODULE_VAR MagneticHeading = {PLANE_HEADING_DEGREES_MAGNETIC};
MODULE_VAR ApHeadingLockDir = {AUTOPILOT_HEADING_LOCK_DIR};
MODULE_VAR to_from_flag = {VOR1_TF_FLAG};
MODULE_VAR gps_drives_nav1 = {GPS_DRIVES_NAV1};
MODULE_VAR adf_needle = {ADF_NEEDLE};
MODULE_VAR fuel_weight = {FUEL_WEGHT_PER_GALLON};
MODULE_VAR fuel_left_main = {FUEL_QUANTITY_LEFT};
MODULE_VAR fuel_right_main = {FUEL_QUANTITY_RIGHT};
MODULE_VAR engine2_oil_qty = {ENGINE2_OIL_QUANTITY};
MODULE_VAR engine1_oil_qty = {ENGINE1_OIL_QUANTITY};
MODULE_VAR engine2_oil_temp = {ENGINE2_OIL_TEMPERATURE};
MODULE_VAR engine1_oil_temp = {ENGINE1_OIL_TEMPERATURE};
MODULE_VAR engine2_oil_press = {ENGINE2_OIL_PRESSURE};
MODULE_VAR engine1_oil_press = {ENGINE1_OIL_PRESSURE};
MODULE_VAR spoilers_armed = {SPOILERS_ARMED};

/*
 * global variables
 */
UINT mach_1 = 0;
UINT mach_10 = 0;
UINT speed_1 = 0;
UINT speed_10 = 0;
UINT speed_100 = 0;
FLOAT64 fMach = 0;
UINT baro_alt_tenths = 0;
UINT baro_alt_hund = 0;
UINT baro_alt_thous = 0;
UINT baro_alt_ten_thous = 0;
UINT isDme1 = 1;
FLOAT64 fVor1Needle=0;
FLOAT64 fDegreesGyro = 0;
FLOAT64 FSeconds = 0;
FLOAT64 fVor2Radial = 0;
FLOAT64 fHsiHdgBugDelta = 0;
FLOAT64 fMagneticHeading = 0;
FLOAT64 fApHeadingLockDir = 0;
UINT uom = UOM_FEET;
FLOAT64 fRmiAdfNeedle = 0;
FLOAT64 fEngine2OilQty=0;
FLOAT64 fEngine1OilQty=0;
FLOAT64 fEngine2OilTemp=0;
FLOAT64 fEngine1OilTemp=0;
FLOAT64 fEngine2OilPress=0;
FLOAT64 fEngine1OilPress=0;
FLOAT64 fMachSpeed = 0;
FLOAT64 fTat = 0;

BOOL bPanelLightOn = FALSE;
BOOL bHsiModeArc = TRUE;
/*
 * return current units of measure
 */
UINT GetUnits(void)
{
	lookup_var(&units_of_measure);
	return (UNITS_OF_MEASURE)units_of_measure.var_value.n;
}

/*
 * autopilot
 */
#define     GAUGE_NAME          "Autopilot"
#define     GAUGEHDR_VAR_NAME   gaugehdr_autopilot
#define     GAUGE_W				706

#include "autoplt.c"

/*
 * airspeed
 */
#define     GAUGE_NAME          "Airspeed"
#define     GAUGEHDR_VAR_NAME   gaugehdr_airspeed
#define     GAUGE_W				181

#include "airspeed.c"

/*
 * flaps
 */
#define     GAUGE_NAME          "Flaps"
#define     GAUGEHDR_VAR_NAME   gaugehdr_flaps
#define     GAUGE_W				88

#include "flaps.c"

/*
 * altimeter
 */
#define     GAUGE_NAME          "Altimeter"
#define     GAUGEHDR_VAR_NAME   gaugehdr_altimeter
#define     GAUGE_W				130

#include "altimet.c"

/*
 * wiskey compass
 */
#define     GAUGE_NAME          "WiskeyCompass"
#define     GAUGEHDR_VAR_NAME   gaugehdr_wiskey
#define     GAUGE_W				57

#include "wiskey.c"

/*
 * adi
 */
#define     GAUGE_NAME          "Adi"
#define     GAUGEHDR_VAR_NAME   gaugehdr_adi
#define     GAUGE_W				244

#include "adi.c"

/*
 * chronometer
 */
#define     GAUGE_NAME          "Chronometer"
#define     GAUGEHDR_VAR_NAME   gaugehdr_chrono
#define     GAUGE_W				90

#include "chrono.c"

/*
 * clock
 */
#define     GAUGE_NAME          "Clock"
#define     GAUGEHDR_VAR_NAME   gaugehdr_clock
#define     GAUGE_W				120

#include "clock.c"

/*
 * com 2 radio
 */
#define     GAUGE_NAME          "Comm2Freq"
#define     GAUGEHDR_VAR_NAME   gaugehdr_comm2_freq
#define     GAUGE_W				55

#include "com2freq.c"


/*
 * right radio stack
 */
#define     GAUGE_NAME          "AdfFreq"
#define     GAUGEHDR_VAR_NAME   gaugehdr_adf_freq
#define     GAUGE_W				55

#include "adf_freq.c"

/*
 * eicas 1
 */
#define     GAUGE_NAME          "Eicas1"
#define     GAUGEHDR_VAR_NAME   gaugehdr_eicas1
#define     GAUGE_W				154

#include "eicas1.c"

/*
 * mini gps
 */
#define     GAUGE_NAME          "MiniGps"
#define     GAUGEHDR_VAR_NAME   gaugehdr_gps
#define     GAUGE_W				90

#include "gps.c"

/*
 * dme
 */
#define     GAUGE_NAME          "Dme"
#define     GAUGEHDR_VAR_NAME   gaugehdr_dme
#define     GAUGE_W				175

#include "dme.c"

/*
 * tape altimeter
 */
#define     GAUGE_NAME          "TapeAltimeter"
#define     GAUGEHDR_VAR_NAME   gaugehdr_tapealt
#define     GAUGE_W				23

#include "tapealt.c"

/*
 * wing lights switch
 */
#define     GAUGE_NAME          "WingLights"
#define     GAUGEHDR_VAR_NAME   gaugehdr_wls
#define     GAUGE_W				33

#include "winglite.c"

/*
 * logo lights switch
 */
#define     GAUGE_NAME          "LogoLights"
#define     GAUGEHDR_VAR_NAME   gaugehdr_logo_lights
#define     GAUGE_W				33

#include "logolite.c"

/*
 * vsi
 */
#define     GAUGE_NAME          "Vsi"
#define     GAUGEHDR_VAR_NAME   gaugehdr_vsi
#define     GAUGE_W				90

#include "vsi.c"

/*
 * taxi lights switch
 */
#define     GAUGE_NAME          "TaxiLights"
#define     GAUGEHDR_VAR_NAME   gaugehdr_taxi_lights
#define     GAUGE_W				33

#include "taxilite.c"

/*
 * beacon lights switch
 */
#define     GAUGE_NAME          "BeaconLights"
#define     GAUGEHDR_VAR_NAME   gaugehdr_beacon_lights
#define     GAUGE_W				33

#include "beaclite.c"

/*
 * panel lights switch
 */
#define     GAUGE_NAME          "PanelLights"
#define     GAUGEHDR_VAR_NAME   gaugehdr_panel_lights
#define     GAUGE_W				33

#include "panelite.c"

/*
 * other lights switches
 */
#define     GAUGE_NAME          "Lights"
#define     GAUGEHDR_VAR_NAME   gaugehdr_lights
#define     GAUGE_W				325

#include "lights.c"

/*
 * gear lever
 */
#define     GAUGE_NAME          "GearLever"
#define     GAUGEHDR_VAR_NAME   gaugehdr_gear_lever
#define     GAUGE_W				35

#include "gearlvr.c"

/*
 * gear lights
 */
#define     GAUGE_NAME          "GearLights"
#define     GAUGEHDR_VAR_NAME   gaugehdr_gear_lights
#define     GAUGE_W				58

#include "gearlite.c"

/*
 * hsi
 */
//#define     GAUGE_NAME          "Hsi"
//#define     GAUGEHDR_VAR_NAME   gaugehdr_hsi
//#define     GAUGE_W				220

//#include "hsi.c"

/*
 * nav1 freq
 */
#define     GAUGE_NAME          "Nav1Freq"
#define     GAUGEHDR_VAR_NAME   gaugehdr_nav1_freq
#define     GAUGE_W				55

#include "nav1freq.c"

/*
 * nav2 freq
 */
#define     GAUGE_NAME          "Nav2Freq"
#define     GAUGEHDR_VAR_NAME   gaugehdr_nav2_freq
#define     GAUGE_W				55

#include "nav2freq.c"

/*
 * comm1 freq
 */
#define     GAUGE_NAME          "Comm1Freq"
#define     GAUGEHDR_VAR_NAME   gaugehdr_comm1_freq
#define     GAUGE_W				55

#include "com1freq.c"

/*
 * transponder freq
 */
#define     GAUGE_NAME          "XpdrFreq"
#define     GAUGEHDR_VAR_NAME   gaugehdr_xpdr_freq
#define     GAUGE_W				55

#include "xpdrfreq.c"

/*
 * temperature
 */
#define     GAUGE_NAME          "Temperature"
#define     GAUGEHDR_VAR_NAME   gaugehdr_temp
#define     GAUGE_W				90

#include "temp.c"

/*
 * rmi
 */
#define     GAUGE_NAME          "Rmi"
#define     GAUGEHDR_VAR_NAME   gaugehdr_rmi
#define     GAUGE_W				118

#include "rmi.c"

/*
 * fuel
 */
#define     GAUGE_NAME          "Fuel"
#define     GAUGEHDR_VAR_NAME   gaugehdr_fuel
#define     GAUGE_W				152

#include "fuel.c"

/*
 * oil
 */
#define     GAUGE_NAME          "Oil"
#define     GAUGEHDR_VAR_NAME   gaugehdr_oil
#define     GAUGE_W				88

#include "oil.c"

/*
 * omi
 */
#define     GAUGE_NAME          "Omi"
#define     GAUGEHDR_VAR_NAME   gaugehdr_omi
#define     GAUGE_W				45

#include "omi.c"

/*
 * spoiler
 */
#define     GAUGE_NAME          "Spoilers"
#define     GAUGEHDR_VAR_NAME   gaugehdr_spoiler
#define     GAUGE_W				70

#include "spoiler.c"

/*
 * engine start
 */
#define     GAUGE_NAME          "EngineStarter"
#define     GAUGEHDR_VAR_NAME   gaugehdr_start
#define     GAUGE_W				150

#include "start.c"

/*
 * backup altimeter
 */
#define     GAUGE_NAME          "BackupAltimeter"
#define     GAUGEHDR_VAR_NAME   gaugehdr_backup_altimeter
#define     GAUGE_W				122

#include "back_alt.c"

/*
 * backup attitude
 */
#define     GAUGE_NAME          "BackupAttitude"
#define     GAUGEHDR_VAR_NAME   gaugehdr_backup_attitude
#define     GAUGE_W				126

#include "back_att.c"

/*
 * backup airspeed
 */
#define     GAUGE_NAME          "BackupAirspeed"
#define     GAUGEHDR_VAR_NAME   gaugehdr_backup_airspeed
#define     GAUGE_W				116

#include "bkairspd.c"

/*
 * eicas 2
 */
#define     GAUGE_NAME          "Eicas2"
#define     GAUGEHDR_VAR_NAME   gaugehdr_eicas2
#define     GAUGE_W				140

#include "eicas2.c"

/*
 * thrust levers
 */
#define     GAUGE_NAME          "ThrottleLever"
#define     GAUGEHDR_VAR_NAME   gaugehdr_throttle
#define     GAUGE_W				125

#include "throttle.c"

/*
 * flaps lever
 */
#define     GAUGE_NAME          "FlapsLever"
#define     GAUGEHDR_VAR_NAME   gaugehdr_flaps_lever
#define     GAUGE_W				40

#include "flever.c"

/*
 * trim indicator
 */
#define     GAUGE_NAME          "TrimIndicator"
#define     GAUGEHDR_VAR_NAME   gaugehdr_trim_indicator
#define     GAUGE_W				90

#include "trim.c"

/*
 * trim indicator
 */
#define     GAUGE_NAME          "Signs"
#define     GAUGEHDR_VAR_NAME   gaugehdr_signs
#define     GAUGE_W				110

#include "signs.c"

/*
 * eicas 3
 */
#define     GAUGE_NAME          "Eicas3"
#define     GAUGEHDR_VAR_NAME   gaugehdr_eicas3
#define     GAUGE_W				85

#include "eicas3.c"

/*
 * yoke
 */
#define     GAUGE_NAME          "Yoke"
#define     GAUGEHDR_VAR_NAME   gaugehdr_yoke
#define     GAUGE_W				499

#include "yoke.c"

/*
 * audio
 */
#define     GAUGE_NAME          "Audio"
#define     GAUGEHDR_VAR_NAME   gaugehdr_audio
#define     GAUGE_W				14

#include "audio.c"

/*
 * autobrake
 */
#define     GAUGE_NAME          "AutobrakeSwitch"
#define     GAUGEHDR_VAR_NAME   gaugehdr_autobrake
#define     GAUGE_W				70

#include "autobrk.c"

/*
 * flaps lights
 */
#define     GAUGE_NAME          "FlapLights"
#define     GAUGEHDR_VAR_NAME   gaugehdr_flaps_lights
#define     GAUGE_W				62

#include "flap_lt.c"

/*
 * avionics master switch
 */
#define     GAUGE_NAME          "AvionicsMasterSwitch"
#define     GAUGEHDR_VAR_NAME   gaugehdr_avionics_switch
#define     GAUGE_W				17

#include "avmaster.c"

/*
 * seat position
 */
#define     GAUGE_NAME          "SeatPosition"
#define     GAUGEHDR_VAR_NAME   gaugehdr_seat_pos
#define     GAUGE_W				40

#include "seatpos.c"


/*
 * hsi switch
 */
#define     GAUGE_NAME          "HsiSwitch"
#define     GAUGEHDR_VAR_NAME   gaugehdr_hsi_switch
#define     GAUGE_W				29

#include "hsi_sw.c"


/*
 * new style (E)hsi
 */
#define     GAUGE_NAME          "Ehsi"
#define     GAUGEHDR_VAR_NAME   gaugehdr_ehsi
#define     GAUGE_W				244

#include "new_hsi.c"

/*
 * deice switch
 */
#define     GAUGE_NAME          "AntiIce"
#define     GAUGEHDR_VAR_NAME   gaugehdr_deice
#define     GAUGE_W				29

#include "deice.c"


/////////////////////////////////////////////////////////////////////////////
// Gauge table entries
/////////////////////////////////////////////////////////////////////////////
GAUGE_TABLE_BEGIN()
	GAUGE_TABLE_ENTRY(&gaugehdr_autopilot)
	GAUGE_TABLE_ENTRY(&gaugehdr_airspeed)
	GAUGE_TABLE_ENTRY(&gaugehdr_flaps)
	GAUGE_TABLE_ENTRY(&gaugehdr_altimeter)
	GAUGE_TABLE_ENTRY(&gaugehdr_wiskey)
	GAUGE_TABLE_ENTRY(&gaugehdr_adi)
	GAUGE_TABLE_ENTRY(&gaugehdr_chrono)
	GAUGE_TABLE_ENTRY(&gaugehdr_clock)
	GAUGE_TABLE_ENTRY(&gaugehdr_comm2_freq)
	GAUGE_TABLE_ENTRY(&gaugehdr_adf_freq)
	GAUGE_TABLE_ENTRY(&gaugehdr_eicas1)
	GAUGE_TABLE_ENTRY(&gaugehdr_gps)
	GAUGE_TABLE_ENTRY(&gaugehdr_dme)
	GAUGE_TABLE_ENTRY(&gaugehdr_tapealt)
	GAUGE_TABLE_ENTRY(&gaugehdr_wls)
	GAUGE_TABLE_ENTRY(&gaugehdr_logo_lights)
	GAUGE_TABLE_ENTRY(&gaugehdr_vsi)
	GAUGE_TABLE_ENTRY(&gaugehdr_taxi_lights)
	GAUGE_TABLE_ENTRY(&gaugehdr_beacon_lights)
	GAUGE_TABLE_ENTRY(&gaugehdr_panel_lights)
	GAUGE_TABLE_ENTRY(&gaugehdr_lights)
	GAUGE_TABLE_ENTRY(&gaugehdr_gear_lever)
	GAUGE_TABLE_ENTRY(&gaugehdr_gear_lights)
	// GAUGE_TABLE_ENTRY(&gaugehdr_hsi)
	GAUGE_TABLE_ENTRY(&gaugehdr_nav1_freq)
	GAUGE_TABLE_ENTRY(&gaugehdr_nav2_freq)
	GAUGE_TABLE_ENTRY(&gaugehdr_comm1_freq)
	GAUGE_TABLE_ENTRY(&gaugehdr_xpdr_freq)
	GAUGE_TABLE_ENTRY(&gaugehdr_temp)
	GAUGE_TABLE_ENTRY(&gaugehdr_rmi)
	GAUGE_TABLE_ENTRY(&gaugehdr_fuel)
	GAUGE_TABLE_ENTRY(&gaugehdr_oil)
	GAUGE_TABLE_ENTRY(&gaugehdr_omi)
	GAUGE_TABLE_ENTRY(&gaugehdr_spoiler)
	GAUGE_TABLE_ENTRY(&gaugehdr_start)
	GAUGE_TABLE_ENTRY(&gaugehdr_backup_altimeter)
	GAUGE_TABLE_ENTRY(&gaugehdr_backup_attitude)
	GAUGE_TABLE_ENTRY(&gaugehdr_backup_airspeed)
	GAUGE_TABLE_ENTRY(&gaugehdr_eicas2)
	GAUGE_TABLE_ENTRY(&gaugehdr_throttle)
	GAUGE_TABLE_ENTRY(&gaugehdr_flaps_lever)
	GAUGE_TABLE_ENTRY(&gaugehdr_trim_indicator)
	GAUGE_TABLE_ENTRY(&gaugehdr_signs)
	GAUGE_TABLE_ENTRY(&gaugehdr_eicas3)
	GAUGE_TABLE_ENTRY(&gaugehdr_yoke)
	GAUGE_TABLE_ENTRY(&gaugehdr_audio)
	GAUGE_TABLE_ENTRY(&gaugehdr_autobrake)
	GAUGE_TABLE_ENTRY(&gaugehdr_flaps_lights)
	GAUGE_TABLE_ENTRY(&gaugehdr_avionics_switch)
	GAUGE_TABLE_ENTRY(&gaugehdr_seat_pos)
	GAUGE_TABLE_ENTRY(&gaugehdr_hsi_switch)
	GAUGE_TABLE_ENTRY(&gaugehdr_ehsi)
	GAUGE_TABLE_ENTRY(&gaugehdr_deice)
GAUGE_TABLE_END()



