/*
 * $Id: eicas3.c,v 1.1 2004/09/16 16:43:31 alexanto Exp Alessandro $
 *
 * $Boeing 767 Gauge Pack - (C) 2004 Alessandro Antonini, Central Park Informatica $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Desc: The eicas 3 gauge $
 *
 * $Log: eicas3.c,v $
 * Revision 1.1  2004/09/16 16:43:31  alexanto
 * Initial revision
 *
 */

/*
 *  Set up gauge header
 */
char eicas3_gauge_name[]	= 	GAUGE_NAME;
extern PELEMENT_HEADER      eicas3_list;
extern MOUSERECT            eicas3_rect[];


/*
 * forward declarations
 */
PELEMENT_HEADER eicas3_bg_list[];

void FSAPI eicas3_gaugeproc(PGAUGEHDR, int, UINT32 );

GAUGE_HEADER_FS700( GAUGE_W, eicas3_gauge_name, &eicas3_list, \
					eicas3_rect, eicas3_gaugeproc, 0, 0, 0);

FLOAT64 FSAPI eicas3_elevator_deflection_slider_cb(PELEMENT_SLIDER);
FLOAT64 FSAPI eicas3_rudder_deflection_slider_cb(PELEMENT_SLIDER);
FLOAT64 FSAPI eicas3_aileron_deflection_slider_cb(PELEMENT_SLIDER);

FAILURE_RECORD eicas3_elevator_deflection_slider_fail[] =
{
   {FAIL_SYSTEM_ELECTRICAL_PANELS, FAIL_ACTION_NO_DRAW},
   {FAIL_SYSTEM_ELECTRICAL_AVIONICS, FAIL_ACTION_NO_DRAW},
   {FAIL_NONE, FAIL_ACTION_NONE}
};
FAILURE_RECORD eicas3_rudder_deflection_slider_fail[] =
{
   {FAIL_SYSTEM_ELECTRICAL_PANELS, FAIL_ACTION_NO_DRAW},
   {FAIL_SYSTEM_ELECTRICAL_AVIONICS, FAIL_ACTION_NO_DRAW},
   {FAIL_NONE, FAIL_ACTION_NONE}
};
FAILURE_RECORD eicas3_aileron_deflection_slider_fail[] =
{
   {FAIL_SYSTEM_ELECTRICAL_PANELS, FAIL_ACTION_NO_DRAW},
   {FAIL_SYSTEM_ELECTRICAL_AVIONICS, FAIL_ACTION_NO_DRAW},
   {FAIL_NONE, FAIL_ACTION_NONE}
};

/*
 * pitch slider
 */
MAKE_SLIDER
(    
	eicas3_elevator_deflection_slider,
    BMP_EICAS3_VERT_SLIDER,
	NULL,
	eicas3_elevator_deflection_slider_fail,
	IMAGE_USE_TRANSPARENCY | IMAGE_USE_ERASE,
	0,
	{ 4, 99 },
	MODULE_VAR_NONE, NULL, 0.000000,
	ELEVATOR_DEFLECTION, eicas3_elevator_deflection_slider_cb, -0.88
)

/*
 * rudder slider
 */
MAKE_SLIDER
(    
	eicas3_rudder_deflection_slider,
    BMP_EICAS3_HORIZ_SLIDER,
	NULL,
	eicas3_rudder_deflection_slider_fail,
	IMAGE_USE_TRANSPARENCY | IMAGE_USE_ERASE,
	0,
	{ 47, 131 },
	RUDDER_DEFLECTION, eicas3_rudder_deflection_slider_cb, 0.84,
	MODULE_VAR_NONE, NULL, 0.000000
)

/*
 * aileron slider
 */
MAKE_SLIDER
(    
	eicas3_aileron_deflection_slider,
    BMP_EICAS3_HORIZ_SLIDER,
	NULL,
	eicas3_aileron_deflection_slider_fail,
	IMAGE_USE_TRANSPARENCY | IMAGE_USE_ERASE,
	0,
	{ 47, 105 },
	AILERON_DEFLECTION, eicas3_aileron_deflection_slider_cb, 1,
	MODULE_VAR_NONE, NULL, 0.000000
)


/*
 * card background image
 */
MAKE_STATIC
(
    eicas3_bg,
    BMP_EICAS3_BG,
    &eicas3_bg_list,
    NULL,
	IMAGE_USE_TRANSPARENCY | IMAGE_USE_ERASE,
	0,
	0,0
)

/*
 * priority lists
 */
PELEMENT_HEADER eicas3_bg_list[] =
{
	&eicas3_elevator_deflection_slider.header,
	&eicas3_rudder_deflection_slider.header,
	&eicas3_aileron_deflection_slider.header,
	NULL
};


extern PELEMENT_HEADER      eicas3_list = &eicas3_bg.header;


MOUSE_BEGIN(eicas3_rect, HELP_NONE, 0, 0 )
MOUSE_END

FLOAT64 FSAPI eicas3_elevator_deflection_slider_cb(PELEMENT_SLIDER pelement)
{
	return pelement->source_var_y.var_value.n*180/PI;
}
FLOAT64 FSAPI eicas3_rudder_deflection_slider_cb(PELEMENT_SLIDER pelement)
{
	return pelement->source_var_x.var_value.n*180/PI;
}
FLOAT64 FSAPI eicas3_aileron_deflection_slider_cb(PELEMENT_SLIDER pelement)
{
	return pelement->source_var_x.var_value.n*180/PI;
}



#undef		GAUGE_NAME
#undef		GAUGEHDR_VAR_NAME
#undef		GAUGE_W


/*
 * gauge proc
 */
void FSAPI eicas3_gaugeproc(PGAUGEHDR pgauge, int service_id, UINT32 extra_data)
{
	switch(service_id)
	{
	case PANEL_SERVICE_PRE_INSTALL: /* "install_routine()" */
		break;

	case PANEL_SERVICE_PRE_INITIALIZE:	/* "initialize_routine()" */
		break;

	case PANEL_SERVICE_PRE_UPDATE: /* "update_routine()" */
		if (bPanelLightOn) // if panel lights on, brighten elements
		{
			BRIGHT_IMG(pgauge->elements_list[0]);
			BRIGHT_IMG(pgauge->elements_list[0]->next_element[0]);
			BRIGHT_IMG(pgauge->elements_list[0]->next_element[1]);
			BRIGHT_IMG(pgauge->elements_list[0]->next_element[2]);
		}
		else
		{
			DARK_IMG(pgauge->elements_list[0]);
			DARK_IMG(pgauge->elements_list[0]->next_element[0]);
			DARK_IMG(pgauge->elements_list[0]->next_element[1]);
			DARK_IMG(pgauge->elements_list[0]->next_element[2]);
		}
		break;

	case PANEL_SERVICE_PRE_DRAW: /* "draw_routine()" */
		break;

	case PANEL_SERVICE_PRE_KILL: /* "kill_routine()" */
		break;
	}

}
