/*
 * $Id: gps.c,v 1.1 2004/09/16 16:43:31 alexanto Exp Alessandro $
 *
 * $Boeing 767 Gauge Pack - (C) 2004 Alessandro Antonini, Central Park Informatica $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Desc: The mini gps gauge $
 *
 * $Log: gps.c,v $
 * Revision 1.1  2004/09/16 16:43:31  alexanto
 * Initial revision
 *
 */

/*
 *  Set up gauge header
 */
char gps_gauge_name[]     = GAUGE_NAME;
extern PELEMENT_HEADER      gps_list;
extern MOUSERECT            gps_rect[];

static int nGpsActive = 1;

/*
 * forward declarations
 */
void FSAPI gps_gaugeproc(PGAUGEHDR, int, UINT32);

GAUGE_HEADER_FS700(GAUGE_W, gps_gauge_name, &gps_list, \
                        gps_rect, gps_gaugeproc, 0, 0, 0);

FLOAT64 FSAPI gps_wp_bearing_string_cb(PELEMENT_STRING);
FLOAT64 FSAPI gps_wp_distance_string_cb(PELEMENT_STRING);
FLOAT64 FSAPI gps_tke_slider_cb(PELEMENT_SLIDER);
MODULE_VAR gps_bearing = {GPS_WP_BEARING};
MODULE_VAR gps_ground_track = {GPS_GROUND_TRACK};

FLOAT64 FBearing = 0, FGroundTrack = 0;


FAILURE_RECORD	gps_wp_bearing_string_fail[] =
{
	{FAIL_SYSTEM_ELECTRICAL_PANELS, FAIL_ACTION_NO_DRAW},
	{FAIL_SYSTEM_ELECTRICAL_AVIONICS, FAIL_ACTION_NO_DRAW},
	{FAIL_NONE, FAIL_ACTION_NONE}
};
FAILURE_RECORD	gps_wp_distance_string_fail[] =
{
	{FAIL_SYSTEM_ELECTRICAL_PANELS, FAIL_ACTION_NO_DRAW},
	{FAIL_SYSTEM_ELECTRICAL_AVIONICS, FAIL_ACTION_NO_DRAW},
	{FAIL_NONE, FAIL_ACTION_NONE}
};
FAILURE_RECORD	gps_tke_slider_fail[] =
{
	{FAIL_SYSTEM_ELECTRICAL_PANELS, FAIL_ACTION_NO_DRAW},
	{FAIL_SYSTEM_ELECTRICAL_AVIONICS, FAIL_ACTION_NO_DRAW},
	{FAIL_NONE, FAIL_ACTION_NONE}
};

/*
 * bearing to next waypoint
 */
MAKE_STRING( gps_wp_bearing_string,	NULL, gps_wp_bearing_string_fail,
	IMAGE_USE_ERASE | transparent,	0,	{107, 121},	{125, 48}, 5,
    MODULE_VAR_NONE, MODULE_VAR_NONE, MODULE_VAR_NONE,
	CL_LIME, RGB(4,4,4), RGB(255,255, 255), FONT_QUARTZ,
	GAUGE_WEIGHT_DEFAULT, DEFAULT_CHARSET,
	0,DT_VCENTER | DT_SINGLELINE | DT_CENTER,
	NULL, gps_wp_bearing_string_cb )

/*
 * distance to next waypoint
 */
MAKE_STRING( gps_wp_distance_string, NULL, gps_wp_distance_string_fail,
	IMAGE_USE_ERASE | transparent,	0,	{107, 189},	{100, 48}, 4,
    GPS_WP_DISTANCE, MODULE_VAR_NONE, MODULE_VAR_NONE,
	CL_LIME, RGB(4,4,4), RGB(255,255, 255), FONT_QUARTZ,
	GAUGE_WEIGHT_DEFAULT, DEFAULT_CHARSET,
	0,DT_VCENTER | DT_SINGLELINE | DT_CENTER,
	NULL, gps_wp_distance_string_cb )


/*
 * tke slider
 */
MAKE_SLIDER
(
	gps_tke_slider,
	BMP_GPS_SLIDER,
	NULL,
	gps_tke_slider_fail,
	IMAGE_USE_TRANSPARENCY | IMAGE_USE_ERASE,
	0,
	{ 141, 22 },
	MODULE_VAR_NONE, gps_tke_slider_cb, 2,
	MODULE_VAR_NONE, NULL, 0
)


PELEMENT_HEADER gps_bg_list[] =
{
	&gps_wp_bearing_string.header,
	&gps_wp_distance_string.header,
	&gps_tke_slider.header,
	NULL
};

/*
 * card background image
 */
MAKE_STATIC
(
    gps_background,
    BMP_GPS_BG,
    &gps_bg_list,
    NULL,
	IMAGE_USE_ERASE  | IMAGE_USE_TRANSPARENCY,
	0,
	0,0
)


////////////////////////////////////////////////////////////////////////////////
// header
////////////////////////////////////////////////////////////////////////////////
PELEMENT_HEADER     gps_list   = &gps_background.header;

/*
 * switch power
 */
BOOL FSAPI SwitchGpsPower(PPIXPOINT relative_point, FLAGS32 mouse_flags)
{
	nGpsActive = !nGpsActive;
	MFSSoundResPlay(main_sound, FALSE);
	return FALSE;
}

/*
 * switch gps/nav
 */
BOOL FSAPI SwitchGpsNav(PPIXPOINT relative_point, FLAGS32 mouse_flags)
{
	MFSSoundResPlay(main_sound, FALSE);
	trigger_key_event(KEY_TOGGLE_GPS_DRIVES_NAV1,1);
	return FALSE;
}

/*
 * switch gps/flightplan
 */
BOOL FSAPI SwitchGpsFp(PPIXPOINT relative_point, FLAGS32 mouse_flags)
{
	MFSSoundResPlay(main_sound, FALSE);
	trigger_key_event(KEY_GPS_FLIGHTPLAN_BUTTON,1);
	return FALSE;
}

/*
 * gauge initialization proc
 */
void FSAPI gps_gaugeproc( PGAUGEHDR pgauge, int service_id, UINT32 extra_data )
{
	switch(service_id)
	{
	case PANEL_SERVICE_PRE_INSTALL: /* "install_routine()" */
		break;

	case PANEL_SERVICE_POST_INSTALL: /* "install_routine()" */
		MFSSoundResRegister(main_sound, (HMODULE)extra_data);


	case PANEL_SERVICE_PRE_INITIALIZE:	/* "initialize_routine()" */
		initialize_var(&gps_bearing);
		initialize_var(&gps_ground_track);
		break;

	case PANEL_SERVICE_PRE_UPDATE: /* "update_routine()" */
		lookup_var(&gps_bearing);			// update course, tke...
		lookup_var(&gps_ground_track);
		FBearing = gps_bearing.var_value.n * 180 / PI;
		FGroundTrack = gps_ground_track.var_value.n * 180 / PI;

		if (nGpsActive)
		{
			if (bPanelLightOn)	// if panel lights, brighten all elements
			{
				BRIGHT_IMG(pgauge->elements_list[0]);
				BRIGHT_IMG(pgauge->elements_list[0]->next_element[0]);
				BRIGHT_IMG(pgauge->elements_list[0]->next_element[1]);
				BRIGHT_IMG(pgauge->elements_list[0]->next_element[2]);
			}
			else
			{
				DARK_IMG(pgauge->elements_list[0]);
				DARK_IMG(pgauge->elements_list[0]->next_element[0]);
				DARK_IMG(pgauge->elements_list[0]->next_element[1]);
				DARK_IMG(pgauge->elements_list[0]->next_element[2]);
			}
			SHOW_IMAGE(pgauge->elements_list[0]->next_element[0]);
			SHOW_IMAGE(pgauge->elements_list[0]->next_element[1]);
			SHOW_IMAGE(pgauge->elements_list[0]->next_element[2]);
		}
		else
		{
			DARK_IMG(pgauge->elements_list[0]);
			HIDE_IMAGE(pgauge->elements_list[0]->next_element[0]);
			HIDE_IMAGE(pgauge->elements_list[0]->next_element[1]);
			HIDE_IMAGE(pgauge->elements_list[0]->next_element[2]);
			DARK_IMG(pgauge->elements_list[0]);
		}
		break;

	case PANEL_SERVICE_PRE_DRAW: /* "draw_routine()" */
		break;

	case PANEL_SERVICE_PRE_KILL: /* "kill_routine()" */
		MFSSoundUnregister(main_sound);
		break;
	}
}

////////////////////////////////////////////////////////////////////////////////
MOUSERECT gps_rect[] =
{
	MOUSE_PARENT_BEGIN( 0, 0, 0, 0, HELP_NONE )
		MOUSE_PARENT_BEGIN( 206, 250, 75, 44, HELP_NONE )
			MOUSE_CHILD_FUNCT(0,0,75,44, CURSOR_HAND,
				MOUSE_LEFTSINGLE, SwitchGpsPower)
		MOUSE_PARENT_END

		MOUSE_PARENT_BEGIN( 113, 250, 75, 44, HELPID_GAUGE_NAV_GPS_SWITCH )
			MOUSE_CHILD_FUNCT(0,0,75,44, CURSOR_HAND, MOUSE_LEFTSINGLE, SwitchGpsNav)
		MOUSE_PARENT_END

		MOUSE_PARENT_BEGIN( 19, 250, 75, 44, HELP_NONE )
			MOUSE_CHILD_FUNCT(0,0,75,44, CURSOR_HAND, MOUSE_LEFTSINGLE, SwitchGpsFp)
		MOUSE_PARENT_END
		
	MOUSE_PARENT_END
	{
		MOUSE_RECT_EOL, { 0, 0, 0, 0 }, CURSOR_NONE, HELP_NONE, MOUSE_NONE, 0, NULL, NULL
	}
};

/*
 * update bearing
 */
FLOAT64 FSAPI gps_wp_bearing_string_cb(PELEMENT_STRING pelement)
{
	FLOAT64 f = pelement->source_var[0].var_value.n;
	sprintf(pelement->string, "%3.1f", FBearing);
	return f;
}

FLOAT64 FSAPI gps_wp_distance_string_cb(PELEMENT_STRING pelement)
{
	FLOAT64 f = pelement->source_var[0].var_value.n;
	f = (f / 1000) / 1.8532; // convert to nm
	if (f>=100)
		wsprintf(pelement->string,"%0.4d",(int)f);
	else if (f>=10)
		sprintf(pelement->string,"%2.1f",f);
	else
		sprintf(pelement->string,"%2.2f",f);
	return f;
}

FLOAT64 FSAPI gps_tke_slider_cb(PELEMENT_SLIDER pelement)
{
	FLOAT64 tke = FBearing - FGroundTrack;
	if (tke>50)
		tke = 50;
	else if (tke< -50)
		tke = -50;
	return tke;
}

#undef GAUGE_NAME
#undef GAUGEHDR_VAR_NAME
#undef GAUGE_W


