/*
 * $Id: nav1freq.c,v 1.1 2004/09/16 16:43:31 alexanto Exp Alessandro $
 *
 * $Boeing 767 Gauge Pack - (C) 2004 Alessandro Antonini, Central Park Informatica $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Desc: The nav 1 frequency regulator $
 *
 * $Log: nav1freq.c,v $
 * Revision 1.1  2004/09/16 16:43:31  alexanto
 * Initial revision
 *
 */

/*
 *  Set up gauge header
 */
char nav1_freq_gauge_name[]	= 	GAUGE_NAME;
extern PELEMENT_HEADER      nav1_freq_list;
extern MOUSERECT            nav1_freq_rect[];


/*
 * forward declarations
 */
void FSAPI nav1freq_gaugeproc(PGAUGEHDR, int, UINT32);
FLOAT64 FSAPI nav1_freq_string_cb(PELEMENT_STRING pelement);
PELEMENT_HEADER nav1_freq_bg_list[];
GAUGE_HEADER_FS700( GAUGE_W, nav1_freq_gauge_name, &nav1_freq_list, \
					nav1_freq_rect, nav1freq_gaugeproc, 0, 0, 0);

FAILURE_RECORD	nav1_freq_string_fail[] =
{
	{FAIL_SYSTEM_ELECTRICAL_PANELS, FAIL_ACTION_NO_DRAW},
	{FAIL_SYSTEM_ELECTRICAL_AVIONICS, FAIL_ACTION_NO_DRAW},
	{FAIL_GAUGE_NAVIGATION_VOR1, FAIL_ACTION_FREEZE},
	{FAIL_NONE, FAIL_ACTION_NONE}
};



/*
 * the nav1 frequency string
 */
MAKE_STRING
(
	nav1_freq_string,
	NULL,
	nav1_freq_string_fail,
	IMAGE_USE_ERASE,
	0,
	{0, 0},
	{48, 18},
	6,

	NAV1_FREQUENCY,
	MODULE_VAR_NONE,
	MODULE_VAR_NONE,
	CL_LIME,
	RGB(4,4,4),
	CL_WHITE,
	FONT_QUARTZ,
	GAUGE_WEIGHT_DEFAULT,
	DEFAULT_CHARSET,
	0,
	DT_VCENTER | DT_SINGLELINE | DT_LEFT,
	NULL,
	nav1_freq_string_cb
)



/*
 * card background image
 */
MAKE_STATIC
(
    nav1_freq_bg,
    BMP_NAV_BG,
    &nav1_freq_bg_list,
    NULL,
	IMAGE_USE_ERASE | transparent,
	0,
	0,0
)

/*
 * priority lists
 */
PELEMENT_HEADER nav1_freq_bg_list[] =
{
	&nav1_freq_string.header,
	NULL
};


extern PELEMENT_HEADER      nav1_freq_list = &nav1_freq_bg.header;

MOUSERECT nav1_freq_rect[] =
{
    MOUSE_PARENT_BEGIN( 0, 0, 0, 0, HELP_NONE )
		// vor1 frequency regulator
		MOUSE_PARENT_BEGIN( 0, 0, 55, 20, HELPID_RADIO_NAV1 )
			MOUSE_CHILD_EVENT( 0, 0, 14, 20, CURSOR_DOWNARROW,
				MOUSE_DOWN_REPEAT | MOUSE_LEFTSINGLE, KEY_NAV1_RADIO_WHOLE_DEC )
			MOUSE_CHILD_EVENT( 14, 0, 14, 20, CURSOR_UPARROW,
				MOUSE_DOWN_REPEAT | MOUSE_LEFTSINGLE, KEY_NAV1_RADIO_WHOLE_INC )
			MOUSE_CHILD_EVENT( 28, 0, 14, 20, CURSOR_DOWNARROW,
				MOUSE_DOWN_REPEAT | MOUSE_LEFTSINGLE, KEY_NAV1_RADIO_FRACT_DEC )
			MOUSE_CHILD_EVENT( 42, 0, 13, 20, CURSOR_UPARROW,
					MOUSE_DOWN_REPEAT | MOUSE_LEFTSINGLE, KEY_NAV1_RADIO_FRACT_INC )
		MOUSE_PARENT_END
    MOUSE_PARENT_END
    { MOUSE_RECT_EOL, { 0, 0, 0, 0 }, CURSOR_NONE, HELP_NONE, MOUSE_NONE, 0, NULL, NULL }
};


#undef		GAUGE_NAME
#undef		GAUGEHDR_VAR_NAME
#undef		GAUGE_W

FLOAT64 FSAPI nav1_freq_string_cb(PELEMENT_STRING pelement)
{ 
	UINT32 nFreq = (UINT32)pelement->source_var[0].var_value.d;

	// do bcd conversion
	wsprintf(pelement->string, "1%d%d.%d%d", (nFreq >> 12) & 0x000f,
		(nFreq >> 8) & 0x000f, (nFreq >> 4) & 0x000f, nFreq & 0x000f);
	return (FLOAT64)nFreq;
}


////////////////////////////////////////////////////////////////////////////////
// gauge initialization proc
////////////////////////////////////////////////////////////////////////////////
void FSAPI nav1freq_gaugeproc( PGAUGEHDR pgauge, int service_id, UINT32 extra_data )
{
	switch(service_id)
	{
	case PANEL_SERVICE_PRE_INSTALL:		// install_routine()
		break;

	case PANEL_SERVICE_PRE_INITIALIZE:	// initialize_routine()
		break;

	case PANEL_SERVICE_PRE_UPDATE:		// update_routine()
		if (bPanelLightOn)	// if panel lights, brighten all elements
		{
			BRIGHT_IMG(pgauge->elements_list[0]->N_E[0]);
		}
		else							// otherwise darken them
		{
			DARK_IMG(pgauge->elements_list[0]->N_E[0]);	
    	}
		break;
	case PANEL_SERVICE_PRE_DRAW:		// draw_routine()
		break;

	case PANEL_SERVICE_PRE_KILL:		// kill_routine()
		break;
	}
}
