/*
 * $Id: temp.c,v 1.1 2004/09/16 16:43:31 alexanto Exp Alessandro $
 *
 * $Boeing 767 Gauge Pack - (C) 2004 Alessandro Antonini, Central Park Informatica $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Desc: The temperature gauge $
 *
 * $Log: temp.c,v $
 * Revision 1.1  2004/09/16 16:43:31  alexanto
 * Initial revision
 *
 */

/*
 *  Set up gauge header
 */
char temp_gauge_name[]	= 	GAUGE_NAME;
extern PELEMENT_HEADER      temp_list;
extern MOUSERECT            temp_rect[];


/*
 * forward declarations
 */
void FSAPI temp_gaugeproc(PGAUGEHDR, int, UINT32);
PELEMENT_HEADER temp_bg_list[];

FLOAT64 FSAPI temp_string_cb(PELEMENT_STRING);
FLOAT64 FSAPI temp_icon_cb(PELEMENT_ICON);

GAUGE_HEADER_FS700( GAUGE_W, temp_gauge_name, &temp_list, \
					temp_rect, temp_gaugeproc, 0, 0, 0);


FAILURE_RECORD	temp_string_fail[] =
{
	{FAIL_SYSTEM_ELECTRICAL_PANELS, FAIL_ACTION_NO_DRAW},
	{FAIL_SYSTEM_ELECTRICAL_AVIONICS, FAIL_ACTION_NO_DRAW},
	{FAIL_NONE, FAIL_ACTION_NONE}
};

FAILURE_RECORD	temp_icon_fail[] =
{
	{FAIL_SYSTEM_ELECTRICAL_PANELS, FAIL_ACTION_NO_DRAW},
	{FAIL_SYSTEM_ELECTRICAL_AVIONICS, FAIL_ACTION_NO_DRAW},
	{FAIL_NONE, FAIL_ACTION_NONE}
};


/*
 * temperature icon
 */
MAKE_ICON
(      
	temp_icon,
	BMP_TEMP_ICON_C,
	NULL,
	temp_icon_fail,
	IMAGE_USE_TRANSPARENCY | IMAGE_USE_ERASE,
	0,
	{ 99, 9 },
	MODULE_VAR_NONE, temp_icon_cb,
	ICON_SWITCH_TYPE_SET_CUR_ICON,
	2,
	0.000000,
	0
)



/*
 * the temperature display string
 */
MAKE_STRING
(
	temp_string,
	NULL,
	temp_string_fail,
	IMAGE_USE_ERASE | transparent,
	0,
	{28, 9},
	{60, 29},
	3,

	TOTAL_AIR_TEMP,
	MODULE_VAR_NONE,
	MODULE_VAR_NONE,
	CL_RED,
	RGB(4,4,4),
	CL_WHITE,
	FONT_QUARTZ,
	GAUGE_WEIGHT_DEFAULT,
	DEFAULT_CHARSET,
	0,
	DT_VCENTER | DT_SINGLELINE | DT_LEFT,
	NULL,
	temp_string_cb
)


/*
 * card background image
 */
MAKE_STATIC
(
    temp_bg,
    BMP_TEMP_BG,
    &temp_bg_list,
    NULL,
	IMAGE_USE_ERASE | transparent,
	0,
	0,0
)

/*
 * priority lists
 */
PELEMENT_HEADER temp_bg_list[] =
{
	&temp_string.header,
	&temp_icon.header,
	NULL
};


extern PELEMENT_HEADER      temp_list = &temp_bg.header;

MOUSERECT temp_rect[] =
{
    MOUSE_PARENT_BEGIN( 0, 0, 0, 0, HELPID_B737_TOTAL_AIR_TEMP)
    MOUSE_PARENT_END
    { MOUSE_RECT_EOL, { 0, 0, 0, 0 }, CURSOR_NONE, HELP_NONE, MOUSE_NONE, 0, NULL, NULL }
};


#undef		GAUGE_NAME
#undef		GAUGEHDR_VAR_NAME
#undef		GAUGE_W


////////////////////////////////////////////////////////////////////////////////
// gauge initialization proc
////////////////////////////////////////////////////////////////////////////////
void FSAPI temp_gaugeproc( PGAUGEHDR pgauge, int service_id, UINT32 extra_data )
{
	switch(service_id)
	{
	case PANEL_SERVICE_PRE_INSTALL:		// install_routine()
		break;

	case PANEL_SERVICE_PRE_INITIALIZE:	// initialize_routine()
		break;

	case PANEL_SERVICE_PRE_UPDATE:		// update_routine()
		uom = GetUnits();
		if (bPanelLightOn)	// if panel lights, brighten all elements
		{
			BRIGHT_IMG(pgauge->elements_list[0]->N_E[0]);
			BRIGHT_IMG(pgauge->elements_list[0]->N_E[1]);
		}
		else							// otherwise darken them
		{
			DARK_IMG(pgauge->elements_list[0]->N_E[0]);	
			DARK_IMG(pgauge->elements_list[0]->N_E[1]);	
    	}
		break;
	case PANEL_SERVICE_PRE_DRAW:		// draw_routine()
		break;

	case PANEL_SERVICE_PRE_KILL:		// kill_routine()
		break;
	}
}


/*
 * update temperature string
 */
FLOAT64 FSAPI temp_string_cb(PELEMENT_STRING pelement)
{
	FLOAT64		val = pelement->source_var[0].var_value.n;
	val *= 256;
	fTat = val;
	
	if (UOM_FEET==uom)
		val = val*9/5 +32;

	// limit var
	if ( val > 999 )
		val = 999.0;
	else if( val < -99 )
		val = -99;

	wsprintf(pelement->string, "%3d", (UINT32)val);
	return val;
}

FLOAT64 FSAPI temp_icon_cb(PELEMENT_ICON pelement)
{
	return (UOM_FEET==uom) ? 1 : 0;
}
