/*
 * $Id: vsi.c,v 1.1 2004/09/16 16:43:31 alexanto Exp Alessandro $
 *
 * $Boeing 767 Gauge Pack - (C) 2004 Alessandro Antonini, Central Park Informatica $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Desc: The vsi gauge $
 *
 * $Log: vsi.c,v $
 * Revision 1.1  2004/09/16 16:43:31  alexanto
 * Initial revision
 *
 */

/*
 *  Set up gauge header
 */
char vsi_gauge_name[]     = GAUGE_NAME;
extern PELEMENT_HEADER      vsi_list;
extern MOUSERECT            vsi_rect[];

/*
 * forward declarations
 */
FLOAT64 FSAPI vsi_needle_cb(PELEMENT_NEEDLE);


void FSAPI vsigaugeproc(PGAUGEHDR, int, UINT32);

GAUGE_HEADER_FS700(GAUGE_W, vsi_gauge_name, &vsi_list, \
                        vsi_rect, vsigaugeproc, 0, 0, 0);
						
FAILURE_RECORD vsi_needle_fail[] =
{
   {FAIL_SYSTEM_ELECTRICAL_PANELS, FAIL_ACTION_FREEZE},
   {FAIL_SYSTEM_ELECTRICAL_AVIONICS, FAIL_ACTION_FREEZE},
   {FAIL_SYSTEM_PITOT_STATIC, FAIL_ACTION_ZERO},
   {FAIL_NONE, FAIL_ACTION_NONE}
};

NONLINEARITY vsi_needle_nl[] =
{
   {{ 132,   78}, -6000, 0},
   {{ 120,  110}, -4000, 0},
   {{  98,  127}, -3000, 0},
   {{  67,  132}, -2000, 0},
   {{  47,  127}, -1500, 0},
   {{  27,  112}, -1000, 0},
   {{  12,   70}, 0, 0},
   {{  12,   70}, 0, 0},
   {{  15,   47}, 500, 0},
   {{  27,   29}, 1000, 0},
   {{  47,   16}, 1500, 0},
   {{  67,   10}, 2000, 0},
   {{ 99,   16}, 3000, 0},
   {{ 120,   33}, 4000, 0},
   {{ 132,   64}, 6000, 0}
};
      
// vsi needle
MAKE_NEEDLE
(
	vsi_needle,
	BMP_VSI_NEEDLE,
	NULL,
	vsi_needle_fail,
	IMAGE_USE_TRANSPARENCY | IMAGE_USE_ERASE,
	0,
	{ 67, 71 },
	{ 5, 5 },
	//{ 67, 0 },
	VERTICAL_SPEED,
	vsi_needle_cb,
	vsi_needle_nl,
	6
)


PELEMENT_HEADER vsi_bg_list[] =
{
	&vsi_needle.header,
	NULL
};



/*
 * card background image
 */
MAKE_STATIC
(
    vsi_background,
    BMP_VSI_BG,
    &vsi_bg_list,
    NULL,
	IMAGE_USE_TRANSPARENCY | IMAGE_USE_ERASE,
	0,
	0,0
)


////////////////////////////////////////////////////////////////////////////////
// header
////////////////////////////////////////////////////////////////////////////////
PELEMENT_HEADER     vsi_list   = &vsi_background.header;


// tooltip stuff
static FLOAT64 FSAPI VsiGetVerticalSpeed(FLOAT64 number, ID id,
	PCSTRINGZ string, MODULE_VAR *source_var, PGAUGEHDR gauge)
{
	return source_var->var_value.n/256.0;
}

MOUSE_TOOLTIP_ARGS (VsiVerticalSpeed)
	MOUSE_TOOLTIP_ARG(VERTICAL_SPEED, 0, NULL, NULL, NULL, VsiGetVerticalSpeed, NULL, NULL)
MOUSE_TOOLTIP_ARGS_END


////////////////////////////////////////////////////////////////////////////////
MOUSERECT vsi_rect[] =
{
	MOUSE_PARENT_BEGIN( 0, 0, 0, 0, HELP_NONE )
		MOUSE_PARENT_BEGIN( 3, 3, 145, 145, HELP_NONE )
			MOUSE_TOOLTIP_TEXT_ID(TOOLTIPTEXT_VSI_METERS_PER_SEC, VsiVerticalSpeed)
		MOUSE_PARENT_END
	MOUSE_PARENT_END
	{
		MOUSE_RECT_EOL, { 0, 0, 0, 0 }, CURSOR_NONE, HELP_NONE, MOUSE_NONE, 0, NULL, NULL
	}
};


////////////////////////////////////////////////////////////////////////////////
// gauge initialization proc
////////////////////////////////////////////////////////////////////////////////
void FSAPI vsigaugeproc( PGAUGEHDR pgauge, int service_id, UINT32 extra_data )
{
	switch(service_id)
	{
	case PANEL_SERVICE_PRE_INSTALL: /* "install_routine()" */
		break;

	case PANEL_SERVICE_PRE_INITIALIZE:	/* "initialize_routine()" */
		break;

	case PANEL_SERVICE_PRE_UPDATE: /* "update_routine()" */
		if (bPanelLightOn)	// if panel lights, brighten all elements
		{
			BRIGHT_IMG(pgauge->elements_list[0]);
			BRIGHT_IMG(pgauge->elements_list[0]->N_E[0]);

		}
		else
		{
			DARK_IMG(pgauge->elements_list[0]);
			DARK_IMG(pgauge->elements_list[0]->N_E[0]);
		}
		break;

	case PANEL_SERVICE_PRE_DRAW: /* "draw_routine()" */
		break;

	case PANEL_SERVICE_PRE_KILL: /* "kill_routine()" */
		break;
	}
}



#undef GAUGE_NAME
#undef GAUGEHDR_VAR_NAME
#undef GAUGE_W

FLOAT64 FSAPI vsi_needle_cb(PELEMENT_NEEDLE pelement)
{
	FLOAT64 val = pelement->source_var.var_value.n;
	val = val / 256.0;
	val = (val * METERSTOFEET) * 60.0;
	if (val>6000)
		val=6000;
	else if (val < -6000)
		val = -6000;
	return val;

}
